@@ -1,6 +1,6 @@
 package App::perlmv;
 BEGIN {
-  $App::perlmv::VERSION = '0.38';
+  $App::perlmv::VERSION = '0.39';
 }
 # ABSTRACT: Rename files using Perl code.
 
@@ -38,6 +38,7 @@ sub new {
         codes           => [],
         dry_run         => 0,
         homedir         => $homedir,
+        sort_mode       => 1, # 1 = sort ascibetically, -1 = reverse, 0 = no sort
         overwrite       => 0,
         process_dir     => 1,
         process_symlink => 1,
@@ -65,8 +66,9 @@ sub parse_opts {
         'o|overwrite'     => \$self->{ 'overwrite'     },
         'p|parents'       => \$self->{ 'parents'       },
         'R|recursive'     => \$self->{ 'recursive'     },
-        'r|reverse'       => \$self->{ 'reverse_order' },
+        'r|reverse'       => sub { $self->{sort_mode} = -1 },
         's|show=s'        => \$self->{ 'show'          },
+        'T|no-sort'       => sub { $self->{sort_mode} =  0 },
         'v|verbose'       => \$self->{ 'verbose'       },
         'w|write=s'       => \$self->{ 'write'         },
         'f|files'         => sub { $self->{ 'process_dir'    } = 0 },
@@ -205,6 +207,7 @@ Options:
  -r  (--reverse) reverse order of processing (by default order is asciibetically)
  -S  (--no-symlinks) Do not process symlinks
  -s <NAME> (--show) Show source code for scriptlet
+ -T  (--no-sort) do not sort files (default is sort ascibetically)
  -V  (--version) Print version and exit
  -v  (--verbose) Verbose
  -w <NAME> (--write) Write code specified in -e as scriptlet
@@ -343,7 +346,9 @@ sub run_code {
 
 sub _sort {
     my $self = shift;
-    $self->{reverse_order} ? (reverse sort @_) : (sort @_);
+    $self->{sort_mode} == -1 ? (reverse sort @_) :
+        $self->{sort_mode} == 1 ? (sort @_) :
+            @_;
 }
 
 sub process_items {
@@ -532,7 +537,7 @@ App::perlmv - Rename files using Perl code.
 
 =head1 VERSION
 
-version 0.38
+version 0.39
 
 =head1 DESCRIPTION
 
